@@ -1,5 +1,7 @@
 package AnyEvent::Filesys::Notify::Role::Mac;
 
+# ABSTRACT: Use Mac::FSEvents to watch for changed files
+
 use Moose::Role;
 use namespace::autoclean;
 use AnyEvent;
@@ -34,3 +36,28 @@ sub _init {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+AnyEvent::Filesys::Notify::Role::Mac - Use Mac::FSEvents to watch for changed files
+
+=head1 VERSION
+
+version 0.06
+
+=head1 AUTHOR
+
+Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
